==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManager.md <==
# AwsSystemsManagerStateManager


```text
aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManager
```

```text
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManager')
```



| Illustration | AwsSystemsManagerStateManager | AwsSystemsManagerStateManagerCard | AwsSystemsManagerStateManagerGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManager.png) | ![illustration for AwsSystemsManagerStateManager](../../../aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManager.Local.png) | ![illustration for AwsSystemsManagerStateManagerCard](../../../aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManagerCard.Local.png) | ![illustration for AwsSystemsManagerStateManagerGroup](../../../aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManagerGroup.Local.png) |




## AwsSystemsManagerStateManager

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerStateManager
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManager')

' renders the element
AwsSystemsManagerStateManager('AwsSystemsManagerStateManager', 'Aws Systems Manager State Manager', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerStateManager
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManager')

' renders the element
AwsSystemsManagerStateManager('AwsSystemsManagerStateManager', 'Aws Systems Manager State Manager', 'an optional tech label')
@enduml
```

## AwsSystemsManagerStateManagerCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerStateManagerCard
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManager')

' renders the element
AwsSystemsManagerStateManagerCard('AwsSystemsManagerStateManagerCard', 'Aws Systems Manager State Manager Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerStateManagerCard
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManager')

' renders the element
AwsSystemsManagerStateManagerCard('AwsSystemsManagerStateManagerCard', 'Aws Systems Manager State Manager Card', 'an optional description')
@enduml
```

## AwsSystemsManagerStateManagerGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerStateManagerGroup
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManager')

' renders the element
AwsSystemsManagerStateManagerGroup('AwsSystemsManagerStateManagerGroup', 'Aws Systems Manager State Manager Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerStateManagerGroup
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManager')

' renders the element
AwsSystemsManagerStateManagerGroup('AwsSystemsManagerStateManagerGroup', 'Aws Systems Manager State Manager Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManager.md <==
# AwsSystemsManagerStateManager


```text
aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManager
```

```text
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManager')
```



| Illustration | AwsSystemsManagerStateManager | AwsSystemsManagerStateManagerCard | AwsSystemsManagerStateManagerGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManager.png) | ![illustration for AwsSystemsManagerStateManager](../../../aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManager.Local.png) | ![illustration for AwsSystemsManagerStateManagerCard](../../../aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManagerCard.Local.png) | ![illustration for AwsSystemsManagerStateManagerGroup](../../../aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManagerGroup.Local.png) |




## AwsSystemsManagerStateManager

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerStateManager
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManager')

' renders the element
AwsSystemsManagerStateManager('AwsSystemsManagerStateManager', 'Aws Systems Manager State Manager', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerStateManager
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManager')

' renders the element
AwsSystemsManagerStateManager('AwsSystemsManagerStateManager', 'Aws Systems Manager State Manager', 'an optional tech label')
@enduml
```

## AwsSystemsManagerStateManagerCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerStateManagerCard
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManager')

' renders the element
AwsSystemsManagerStateManagerCard('AwsSystemsManagerStateManagerCard', 'Aws Systems Manager State Manager Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerStateManagerCard
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManager')

' renders the element
AwsSystemsManagerStateManagerCard('AwsSystemsManagerStateManagerCard', 'Aws Systems Manager State Manager Card', 'an optional description')
@enduml
```

## AwsSystemsManagerStateManagerGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerStateManagerGroup
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManager')

' renders the element
AwsSystemsManagerStateManagerGroup('AwsSystemsManagerStateManagerGroup', 'Aws Systems Manager State Manager Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsSystemsManagerStateManagerGroup
include('aws-20210730/Resource/ManagementGovernance/AwsSystemsManagerStateManager')

' renders the element
AwsSystemsManagerStateManagerGroup('AwsSystemsManagerStateManagerGroup', 'Aws Systems Manager State Manager Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
